/* ======================================
 * JFreeChart : a free Java chart library
 * ======================================
 *
 * Project Info:  http://www.jfree.org/jfreechart/index.html
 * Project Lead:  David Gilbert (david.gilbert@object-refinery.com);
 *
 * (C) Copyright 2000-2003, by Object Refinery Limited and Contributors.
 *
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation;
 * either version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * --------------------
 * RectangleAnchor.java
 * --------------------
 * (C) Copyright 2003 by Object Refinery Limited.
 *
 * Original Author:  David Gilbert (for Object Refinery Limited);
 * Contributor(s):   -;
 *
 * $Id: RectangleAnchor.java,v 1.1 2003/11/06 09:34:42 mungady Exp $
 *
 * Changes:
 * --------
 * 31-Oct-2003 (DG);
 */

package org.jfree.ui;

import java.awt.geom.Rectangle2D;
import java.io.Serializable;

/**
 * Used to indicate an anchor point for a rectangle.
 *
 * @author David Gilbert
 */
public class RectangleAnchor implements Serializable {

    /** Center. */
    public static final RectangleAnchor CENTER = new RectangleAnchor("RectangleAnchor.CENTER");

    /** Top. */
    public static final RectangleAnchor TOP = new RectangleAnchor("RectangleAnchor.TOP");

    /** Top-Left. */
    public static final RectangleAnchor TOP_LEFT = new RectangleAnchor("RectangleAnchor.TOP_LEFT");

    /** Top-Right. */
    public static final RectangleAnchor TOP_RIGHT = new RectangleAnchor("RectangleAnchor.TOP_RIGHT");

    /** Bottom. */
    public static final RectangleAnchor BOTTOM = new RectangleAnchor("RectangleAnchor.BOTTOM");

    /** Bottom-Left. */
    public static final RectangleAnchor BOTTOM_LEFT = new RectangleAnchor("RectangleAnchor.BOTTOM_LEFT");

    /** Bottom-Right. */
    public static final RectangleAnchor BOTTOM_RIGHT = new RectangleAnchor("RectangleAnchor.BOTTOM_RIGHT");

    /** Left. */
    public static final RectangleAnchor LEFT = new RectangleAnchor("RectangleAnchor.LEFT");

    /** Right. */
    public static final RectangleAnchor RIGHT = new RectangleAnchor("RectangleAnchor.RIGHT");

    /** The name. */
    private String name;

    /**
     * Private constructor.
     *
     * @param name  the name.
     */
    private RectangleAnchor(String name) {
        this.name = name;
    }

    /**
     * Returns a string representing the object.
     *
     * @return The string.
     */
    public String toString() {
        return this.name;
    }

    /**
     * Returns <code>true</code> if this object is equal to the specified object, and
     * <code>false</code> otherwise.
     *
     * @param o  the other object.
     *
     * @return A boolean.
     */
    public boolean equals(Object o) {

        if (this == o) {
            return true;
        }
        if (!(o instanceof RectangleAnchor)) {
            return false;
        }

        final RectangleAnchor order = (RectangleAnchor) o;
        if (!this.name.equals(order.toString())) {
            return false;
        }

        return true;

    }
    
    /**
     * Returns the x or y coordinate of the specified edge.
     * 
     * @param rectangle  the rectangle.
     * @param edge  the edge.
     * 
     * @return The coordinate.
     */
    public static double[] coordinates(Rectangle2D rectangle, RectangleAnchor edge) {
        double result[] = new double[2];
        if (edge == RectangleAnchor.CENTER) {
            result[0] = rectangle.getCenterX();
            result[1] = rectangle.getCenterY();
        }
        else if (edge == RectangleAnchor.TOP) {
            result[0] = rectangle.getCenterX();
            result[1] = rectangle.getMinY();
        }
        else if (edge == RectangleAnchor.BOTTOM) {
            result[0] = rectangle.getCenterX();
            result[1] = rectangle.getMaxY();
        }
        else if (edge == RectangleAnchor.LEFT) {
            result[0] = rectangle.getMinX();
            result[1] = rectangle.getCenterY();
        }
        else if (edge == RectangleAnchor.RIGHT) {
            result[0] = rectangle.getMaxX();
            result[1] = rectangle.getCenterY();
        }
        else if (edge == RectangleAnchor.TOP_LEFT) {
            result[0] = rectangle.getMinX();
            result[1] = rectangle.getMinY();
        }
        else if (edge == RectangleAnchor.TOP_RIGHT) {
            result[0] = rectangle.getMaxX();
            result[1] = rectangle.getMinY();
        }
        else if (edge == RectangleAnchor.BOTTOM_LEFT) {
            result[0] = rectangle.getMinX();
            result[1] = rectangle.getMaxY();
        }
        else if (edge == RectangleAnchor.BOTTOM_RIGHT) {
            result[0] = rectangle.getMaxX();
            result[1] = rectangle.getMaxY();
        }
        return result;
    }
    
}
